@@ -4,6 +4,7 @@ from pydantic import validate_arguments
 from starlette.middleware import Middleware as StarletteMiddleware
 from starlette.middleware.cors import CORSMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
+from typing_extensions import TypedDict
 
 from starlite.asgi import PathParamPlaceholder, RouteMapNode, StarliteASGIRouter
 from starlite.config import (
@@ -17,7 +18,7 @@ from starlite.config import (
 )
 from starlite.datastructures import State
 from starlite.exceptions import ImproperlyConfiguredException
-from starlite.handlers.asgi import ASGIRouteHandler, asgi
+from starlite.handlers.asgi import asgi
 from starlite.handlers.http import HTTPRouteHandler
 from starlite.middleware.compression.base import CompressionMiddleware
 from starlite.middleware.csrf import CSRFMiddleware
@@ -49,6 +50,7 @@ if TYPE_CHECKING:
     from starlette.types import ASGIApp, Receive, Scope, Send
 
     from starlite.asgi import ComponentsSet, PathParamPlaceholderType
+    from starlite.handlers.asgi import ASGIRouteHandler
     from starlite.handlers.base import BaseRouteHandler
     from starlite.handlers.websocket import WebsocketRouteHandler
     from starlite.routes.base import PathParameterDefinition
@@ -65,10 +67,24 @@ DEFAULT_CACHE_CONFIG = CacheConfig()
 """
 
 
+class HandlerIndex(TypedDict):
+    """This class is used to map route handler names to a mapping of path +
+    route handler.
+
+    It's used in the 'get_handler_index_by_name' utility method.
+    """
+
+    path: str
+    """Full route path to the route handler."""
+    handler: Union[Union["HTTPRouteHandler", "WebsocketRouteHandler", "ASGIRouteHandler"]]
+    """Route handler instance."""
+
+
 class Starlite(Router):
     __slots__ = (
         "_init",
         "_registered_routes",
+        "_route_handler_index",
         "_static_paths",
         "allowed_hosts",
         "asgi_handler",
@@ -116,6 +132,7 @@ class Starlite(Router):
         route_handlers: List[ControllerRouterHandler],
         static_files_config: Optional[Union[StaticFilesConfig, List[StaticFilesConfig]]] = None,
         template_config: Optional[TemplateConfig] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         tags: Optional[List[str]] = None,
     ):
         """The Starlite application.
@@ -161,10 +178,13 @@ class Starlite(Router):
                 function decorated by the route handler decorators.
             static_files_config: An instance or list of [StaticFilesConfig][starlite.config.StaticFilesConfig]
             template_config: An instance of [TemplateConfig][starlite.config.TemplateConfig]
+            security: A list of dictionaries that will be added to the schema of all route handlers in the application. See [SecurityRequirement][pydantic_openapi_schema.v3_1_0.security_requirement.SecurityRequirement] for details.
             tags: A list of string tags that will be appended to the schema of all route handlers under the application.
         """
+
         self._init = False
         self._registered_routes: Set[BaseRoute] = set()
+        self._route_handler_index: Dict[str, HandlerIndex] = {}
         self._static_paths: Set[str] = set()
         self.allowed_hosts = allowed_hosts
         self.cache = cache_config.to_cache()
@@ -174,6 +194,7 @@ class Starlite(Router):
         self.debug = debug
         self.on_shutdown = on_shutdown or []
         self.on_startup = on_startup or []
+        self.openapi_schema: Optional["OpenAPI"] = None
         self.plain_routes: Set[str] = set()
         self.plugins = plugins or []
         self.route_map: RouteMapNode = {}
@@ -194,6 +215,7 @@ class Starlite(Router):
             response_cookies=response_cookies,
             response_headers=response_headers,
             route_handlers=route_handlers,
+            security=security,
             tags=tags,
         )
         self._init = True
@@ -204,10 +226,6 @@ class Starlite(Router):
         for route_handler in route_handlers:
             self.register(route_handler)
 
-        self.asgi_router = StarliteASGIRouter(on_shutdown=self.on_shutdown, on_startup=self.on_startup, app=self)
-        self.asgi_handler = self._create_asgi_handler()
-
-        self.openapi_schema: Optional["OpenAPI"] = None
         if openapi_config:
             self.openapi_schema = openapi_config.create_openapi_schema_model(self)
             self.register(openapi_config.openapi_controller)
@@ -216,6 +234,9 @@ class Starlite(Router):
                 self._static_paths.add(config.path)
                 self.register(asgi(path=config.path)(config.to_static_files_app()))
 
+        self.asgi_router = StarliteASGIRouter(on_shutdown=self.on_shutdown, on_startup=self.on_startup, app=self)
+        self.asgi_handler = self._create_asgi_handler()
+
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
         """The application entry point.
 
@@ -262,6 +283,34 @@ class Starlite(Router):
                 route.handler_parameter_model = route.create_handler_kwargs_model(route.route_handler)
         self._construct_route_map()
 
+    def get_handler_index_by_name(self, name: str) -> Optional[HandlerIndex]:
+        """Receives a route handler name and returns an optional dictionary
+        containing the route handler instance and the path.
+
+        Examples:
+            ```python
+            from starlite import Starlite, get
+
+
+            @get("/", name="my-handler")
+            def handler() -> None:
+                pass
+
+
+            app = Starlite(route_handlers=[handler])
+
+            handler_index = app.get_handler_index_by_name("my-handler")
+
+            # { "path": "/", "handler" ... }
+            ```
+        Args:
+            name: A route handler unique name.
+
+        Returns:
+            A [HandlerIndex][starlite.app.HandlerIndex] instance or None.
+        """
+        return self._route_handler_index.get(name)
+
     def _create_asgi_handler(self) -> "ASGIApp":
         """Creates an ASGIApp that wraps the ASGI router inside an exception
         handler.
@@ -283,7 +332,6 @@ class Starlite(Router):
     def _wrap_in_exception_handler(self, app: "ASGIApp", exception_handlers: ExceptionHandlersMap) -> "ASGIApp":
         """Wraps the given ASGIApp in an instance of
         ExceptionHandlerMiddleware."""
-
         return ExceptionHandlerMiddleware(app=app, exception_handlers=exception_handlers, debug=self.debug)
 
     def _add_node_to_route_map(self, route: BaseRoute) -> RouteMapNode:
@@ -323,6 +371,29 @@ class Starlite(Router):
         self._configure_route_map_node(route, current_node)
         return current_node
 
+    def _add_route_to_handler_index(self, route: BaseRoute) -> None:
+        """Maps route handler names to urls.
+
+        Args:
+            route: A Route instance.
+
+        Returns:
+            None
+        """
+        route_handlers: List[Union["HTTPRouteHandler", "WebsocketRouteHandler", "ASGIRouteHandler"]] = []
+        if isinstance(route, (WebSocketRoute, ASGIRoute)):
+            route_handlers.append(route.route_handler)
+        else:
+            route_handlers.extend(cast("HTTPRoute", route).route_handlers)
+
+        for route_handler in route_handlers:
+            if route_handler.name in self._route_handler_index:
+                raise ImproperlyConfiguredException(
+                    f"route handler names must be unique - {route_handler.name} is not unique."
+                )
+            if route_handler.name:
+                self._route_handler_index[route_handler.name] = HandlerIndex(path=route.path, handler=route_handler)
+
     def _configure_route_map_node(self, route: BaseRoute, node: RouteMapNode) -> None:
         """Set required attributes and route handlers on route_map tree
         node."""
@@ -360,12 +431,13 @@ class Starlite(Router):
             node = self._add_node_to_route_map(route)
             if node["_path_parameters"] != route.path_parameters:
                 raise ImproperlyConfiguredException("Should not use routes with conflicting path parameters")
+            self._add_route_to_handler_index(route)
             self._registered_routes.add(route)
 
     def _build_route_middleware_stack(
         self,
         route: Union[HTTPRoute, WebSocketRoute, ASGIRoute],
-        route_handler: Union[HTTPRouteHandler, "WebsocketRouteHandler", ASGIRouteHandler],
+        route_handler: Union["HTTPRouteHandler", "WebsocketRouteHandler", "ASGIRouteHandler"],
     ) -> "ASGIApp":
         """Constructs a middleware stack that serves as the point of entry for
         each route."""
