@@ -1,8 +1,9 @@
-from typing import TYPE_CHECKING, Dict, List, Optional, Type, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Type, Union, cast
 
 from pydantic import AnyUrl, BaseModel
 from pydantic_openapi_schema import construct_open_api_with_schema_class
 from pydantic_openapi_schema.v3_1_0 import (
+    Components,
     Contact,
     ExternalDocumentation,
     Info,
@@ -50,7 +51,7 @@ class OpenAPIConfig(BaseModel):
     """
     contact: Optional[Contact] = None
     """
-        API contact information, should be an [Contact][pydantic_openapi_schema.v3_10_0.Contact] instance.
+        API contact information, should be an [Contact][pydantic_openapi_schema.v3_1_0.contact.Contact] instance.
     """
     description: Optional[str] = None
     """
@@ -59,21 +60,26 @@ class OpenAPIConfig(BaseModel):
     external_docs: Optional[ExternalDocumentation] = None
     """
         Links to external documentation.
-        Should be an instance of [ExternalDocumentation][pydantic_openapi_schema.v3_10_0.external_documentation.ExternalDocumentation].
+        Should be an instance of [ExternalDocumentation][pydantic_openapi_schema.v3_1_0.external_documentation.ExternalDocumentation].
     """
     license: Optional[License] = None
     """
         API Licensing information.
-        Should be an instance of [License][pydantic_openapi_schema.v3_10_0.license.License].
+        Should be an instance of [License][pydantic_openapi_schema.v3_1_0.license.License].
     """
     security: Optional[List[SecurityRequirement]] = None
     """
         API Security requirements information.
-        Should be an instance of [SecurityRequirement][pydantic_openapi_schema.v3_10_0.security_requirement.SecurityRequirement].
+        Should be an instance of [SecurityRequirement][pydantic_openapi_schema.v3_1_0.security_requirement.SecurityRequirement].
+    """
+    components: Optional[Union[Components, List[Components]]] = None
+    """
+        API Components information.
+        Should be an instance of [Components][pydantic_openapi_schema.v3_10_0.components.Components] or a list thereof.
     """
     servers: List[Server] = [Server(url="/")]
     """
-        A list of [Server][pydantic_openapi_schema.v3_10_0.server.Server] instances.
+        A list of [Server][pydantic_openapi_schema.v3_1_0.server.Server] instances.
     """
     summary: Optional[str] = None
     """
@@ -81,7 +87,7 @@ class OpenAPIConfig(BaseModel):
     """
     tags: Optional[List[Tag]] = None
     """
-        A list of [Tag][pydantic_openapi_schema.v3_10_0.tag.Tag] instances.
+        A list of [Tag][pydantic_openapi_schema.v3_1_0.tag.Tag] instances.
     """
     terms_of_service: Optional[AnyUrl] = None
     """
@@ -93,19 +99,30 @@ class OpenAPIConfig(BaseModel):
     """
     webhooks: Optional[Dict[str, Union[PathItem, Reference]]] = None
     """
-        A mapping of key to either [PathItem][pydantic_openapi_schema.v3_10_0.path_item.PathItem]
-        or [Reference][pydantic_openapi_schema.v3_10_0.reference.Reference] objects.
+        A mapping of key to either [PathItem][pydantic_openapi_schema.v3_1_0.path_item.PathItem]
+        or [Reference][pydantic_openapi_schema.v3_1_0.reference.Reference] objects.
     """
 
     def to_openapi_schema(self) -> OpenAPI:
         """Generates an OpenAPI model.
 
         Returns:
-            pydantic_openapi_schema.v3_10_0.open_api.OpenAPI
+            pydantic_openapi_schema.v3_1_0.open_api.OpenAPI
         """
+        if isinstance(self.components, list):
+            merged_components = Components()
+            for components in self.components:
+                for key in components.__fields__.keys():
+                    value = getattr(components, key, None)
+                    if value:
+                        merged_value_dict = getattr(merged_components, key, {}) or {}
+                        merged_value_dict.update(value)
+                        setattr(merged_components, key, merged_value_dict)
+            self.components = merged_components
         return OpenAPI(
             externalDocs=self.external_docs,
             security=self.security,
+            components=cast("Components", self.components),
             servers=self.servers,
             tags=self.tags,
             webhooks=self.webhooks,
