@@ -1,4 +1,3 @@
-# pylint: disable=too-many-instance-attributes
 from enum import Enum
 from inspect import Signature, isawaitable
 from typing import (
@@ -227,6 +226,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "response_cookies",
         "response_description",
         "response_headers",
+        "security",
         "status_code",
         "summary",
         "sync_to_thread",
@@ -251,6 +251,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         http_method: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]],
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -266,6 +267,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -299,6 +301,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -313,15 +316,11 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -342,12 +341,13 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         else:
             self.status_code = HTTP_200_OK
         super().__init__(
-            path=path,
+            path,
             dependencies=dependencies,
-            guards=guards,
-            opt=opt,
-            middleware=middleware,
             exception_handlers=exception_handlers,
+            guards=guards,
+            middleware=middleware,
+            name=name,
+            opt=opt,
         )
         self.after_request = after_request
         self.after_response = after_response
@@ -371,6 +371,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.response_description = response_description
         self.summary = summary
         self.tags = tags
+        self.security = security
         # memoized attributes, defaulted to Empty
         self._resolved_after_response: Union[Optional[AfterResponseHandler], EmptyType] = Empty
         self._resolved_before_request: Union[Optional[BeforeRequestHandler], EmptyType] = Empty
@@ -488,11 +489,11 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
 
             if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):
                 handler = _create_response_container_handler(
-                    status_code=self.status_code,
-                    headers=headers,
-                    cookies=cookies,
-                    media_type=media_type,
                     after_request=after_request,
+                    cookies=cookies,
+                    headers=headers,
+                    media_type=media_type,
+                    status_code=self.status_code,
                 )
             elif is_class_and_subclass(self.signature.return_annotation, Response):
                 handler = _create_response_handler(cookies=cookies, after_request=after_request)
@@ -594,6 +595,7 @@ class get(HTTPRouteHandler):
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -609,6 +611,7 @@ class get(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -639,6 +642,7 @@ class get(HTTPRouteHandler):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -652,15 +656,11 @@ class get(HTTPRouteHandler):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -682,14 +682,16 @@ class get(HTTPRouteHandler):
             include_in_schema=include_in_schema,
             media_type=media_type,
             middleware=middleware,
+            name=name,
             operation_id=operation_id,
             opt=opt,
             path=path,
             raises=raises,
             response_class=response_class,
-            response_description=response_description,
             response_cookies=response_cookies,
+            response_description=response_description,
             response_headers=response_headers,
+            security=security,
             status_code=status_code,
             summary=summary,
             sync_to_thread=sync_to_thread,
@@ -714,6 +716,7 @@ class post(HTTPRouteHandler):
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -729,6 +732,7 @@ class post(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -759,6 +763,7 @@ class post(HTTPRouteHandler):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -772,15 +777,11 @@ class post(HTTPRouteHandler):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -802,14 +803,16 @@ class post(HTTPRouteHandler):
             include_in_schema=include_in_schema,
             media_type=media_type,
             middleware=middleware,
+            name=name,
             operation_id=operation_id,
             opt=opt,
             path=path,
             raises=raises,
             response_class=response_class,
-            response_description=response_description,
             response_cookies=response_cookies,
+            response_description=response_description,
             response_headers=response_headers,
+            security=security,
             status_code=status_code,
             summary=summary,
             sync_to_thread=sync_to_thread,
@@ -834,6 +837,7 @@ class put(HTTPRouteHandler):
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -849,6 +853,7 @@ class put(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -879,6 +884,7 @@ class put(HTTPRouteHandler):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -892,15 +898,11 @@ class put(HTTPRouteHandler):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -922,14 +924,16 @@ class put(HTTPRouteHandler):
             include_in_schema=include_in_schema,
             media_type=media_type,
             middleware=middleware,
+            name=name,
             operation_id=operation_id,
             opt=opt,
             path=path,
             raises=raises,
             response_class=response_class,
-            response_description=response_description,
             response_cookies=response_cookies,
+            response_description=response_description,
             response_headers=response_headers,
+            security=security,
             status_code=status_code,
             summary=summary,
             sync_to_thread=sync_to_thread,
@@ -954,6 +958,7 @@ class patch(HTTPRouteHandler):
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -969,6 +974,7 @@ class patch(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -999,6 +1005,7 @@ class patch(HTTPRouteHandler):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -1012,15 +1019,11 @@ class patch(HTTPRouteHandler):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -1042,14 +1045,16 @@ class patch(HTTPRouteHandler):
             include_in_schema=include_in_schema,
             media_type=media_type,
             middleware=middleware,
+            name=name,
             operation_id=operation_id,
             opt=opt,
             path=path,
             raises=raises,
             response_class=response_class,
-            response_description=response_description,
             response_cookies=response_cookies,
+            response_description=response_description,
             response_headers=response_headers,
+            security=security,
             status_code=status_code,
             summary=summary,
             sync_to_thread=sync_to_thread,
@@ -1074,6 +1079,7 @@ class delete(HTTPRouteHandler):
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
         middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
@@ -1089,6 +1095,7 @@ class delete(HTTPRouteHandler):
         operation_id: Optional[str] = None,
         raises: Optional[List[Type[HTTPException]]] = None,
         response_description: Optional[str] = None,
+        security: Optional[List[Dict[str, List[str]]]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
     ):
@@ -1119,6 +1126,7 @@ class delete(HTTPRouteHandler):
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
                 valid IANA Media-Type.
             middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
             opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
             response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
                 default response.
@@ -1132,15 +1140,11 @@ class delete(HTTPRouteHandler):
             content_media_type: A string designating the media-type of the content, e.g. "image/png".
             deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
             description: Text used for the route's schema description section.
-            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the
-                OpenAPI schema.
-            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the
-                wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI
-                documentation. This list should describe all exceptions raised within the route handler's
-                function/method. The Starlite ValidationException will be added automatically for the schema if
-                any validation is involved.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
         """
@@ -1162,14 +1166,16 @@ class delete(HTTPRouteHandler):
             include_in_schema=include_in_schema,
             media_type=media_type,
             middleware=middleware,
+            name=name,
             operation_id=operation_id,
             opt=opt,
             path=path,
             raises=raises,
             response_class=response_class,
-            response_description=response_description,
             response_cookies=response_cookies,
+            response_description=response_description,
             response_headers=response_headers,
+            security=security,
             status_code=status_code,
             summary=summary,
             sync_to_thread=sync_to_thread,
