@@ -64,12 +64,14 @@ class Router:
         "response_cookies",
         "response_headers",
         "routes",
+        "security",
         "tags",
     )
 
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
         self,
+        path: str,
         *,
         after_request: Optional[AfterRequestHandler] = None,
         after_response: Optional[AfterResponseHandler] = None,
@@ -79,11 +81,11 @@ class Router:
         guards: Optional[List[Guard]] = None,
         middleware: Optional[List[Middleware]] = None,
         parameters: Optional[ParametersMap] = None,
-        path: str,
         response_class: Optional[ResponseType] = None,
         response_cookies: Optional[ResponseCookies] = None,
         response_headers: Optional[ResponseHeadersMap] = None,
         route_handlers: List[ControllerRouterHandler],
+        security: Optional[List[Dict[str, List[str]]]] = None,
         tags: Optional[List[str]] = None,
     ):
         """The Starlite Router class.
@@ -115,6 +117,7 @@ class Router:
             route_handlers: A required list of route handlers, which can include instances of
                 [Router][starlite.router.Router], subclasses of [Controller][starlite.controller.Controller] or any
                 function decorated by the route handler decorators.
+            security: A list of dictionaries that will be added to the schema of all route handlers under the router.
             tags: A list of string tags that will be appended to the schema of all route handlers under the router.
         """
         self.after_request = after_request
@@ -131,6 +134,7 @@ class Router:
         self.response_cookies = response_cookies or []
         self.response_headers = response_headers or {}
         self.routes: List["BaseRoute"] = []
+        self.security = security
         self.tags = tags or []
 
         for route_handler in route_handlers or []:
@@ -139,10 +143,13 @@ class Router:
     def register(self, value: ControllerRouterHandler) -> List["BaseRoute"]:
         """Register a Controller, Route instance or RouteHandler on the router.
 
-        Accepts a subclass or instance of Controller, an instance of
-        Router or a function/method that has been decorated by any of
-        the routing decorators (e.g. route, get, post...) exported from
-        'starlite.routing'
+        Args:
+            value: a subclass or instance of Controller, an instance of `Router` or a function/method that has been
+                decorated by any of the routing decorators, e.g. [get][starlite.handlers.http.get],
+                [post][starlite.handlers.http.post].
+
+        Returns:
+            Collection of handlers added to the router.
         """
         validated_value = self._validate_registration_value(value)
         routes: List["BaseRoute"] = []
